---
about: Propose a change to the trestle project
assignees: ''
labels: ''
name: Proposed change
title: ''
---
## Instructions: REMOVE before creating issue

- Use this issue template to guide creation of issues. It is not required that all of the fields are filled our or used.

## Issue description / feature objectives

## Completion Criteria

## Expected Behavior

## Actual Behavior

## Steps to Reproduce the Problem

1.
1.
1.

## Specifications

- Version / branch:
- Platform:
- Subsystem:
